@@ -1,3 +1,4 @@
+from dataclasses import asdict
 import signal
 import sys
 
@@ -17,16 +18,20 @@ def main():
     ynapi = YNABAPI()
     mapi = MintAPI()
 
-    ynabs = [y.import_id for y in ynapi.getTransactions()]
-    mints = [mint.asYNAB for mint in mapi.freshMints() if mint.id not in ynabs]
-
-    if not arg('dryrun') and len(mints) > 0:
-        if arg('verbose'):
-            print(f'Posting {len(mints)} transactions to YNAB')
-        ynapi.bulkPostTransactions(mints)
+    ydeez = [y.import_id for y in ynapi.getTransactions()]
+    nabs = [
+        asdict(mint.asYNAB()) for mint in mapi.freshMints()
+        if mint.id not in ydeez
+    ]
+    if arg('verbose'):
+        print(nabs)
+    if not arg('dryrun') and len(nabs) > 0:
+        ynapi.bulkPostTransactions(nabs)
 
 
 def handleArgs():
+    if arg('print_ynab_transactions'):
+        sys.exit(YNABAPI().printTransactions())
     if arg('quickstart'):
         from .quickstart import run
         sys.exit(run())
